==> landers.angular-2.0.77.tgz: package/src/control/directive-landers-pagebar.js <==
;angular.module('Landers.angular')
    .directive('pagebar', ['$compile', 'Flat', function($compile, Flat){
        return {
            restrict : 'A',
            link : function($scope, $ele, $attrs){
                var modelKey = $attrs['modelKey'];
                var pageinfo = Landers.utils.to.bool($attrs['pageinfo']);
                $scope.$watch (modelKey + '.$list', function($list){
                    if ( !$list ) return;

                    var current, total, size, last;
                    if ( $list.page ) {
                        current = '%M%.$list.page.current';
                        total = '%M%.$list.page.total';
                        size = '%M%.$list.page.size';
                        last = '%M%.$list.page.last';
                    } else {
                        current = '%M%.$list.current_page';
                        total = '%M%.$list.total';
                        size = '%M%.$list.per_page';
                        last = '%M%.$list.last_page';
                    }
                    var html = '', paging_action = $attrs['pagingAction'] || '%M%.$event.showPage(page)';
                    html += '<div ng-if="' + last + ' > 0 && ' + total + ' > 0 && ' + size + ' > 0">';
                    if (pageinfo) {
                        html += '<div class="fl page-info">';
                        html += '   <ul class="hlist pageinfo">';
                        html += '       <li>页次：{{' + current + '}}/{{' + last + '}}</li>';
                        html += '       <li class="ml15">每页：{{' + size + '}}</li>';
                        html += '       <li class="ml15">总数：{{' + total + '}}</li>';
                        html += '       <li class="ml15" ng-show="%M%.$items.selected.length">选中: {{%M%.$items.selected.length}}</li>';
                        html += '   </ul>';
                        html += '</div>';
                        html += '<div class="fr">';
                        html += '   <div class="page-num paging" paging page="' + current + '" page-size="' + size + '" total="' + total + '" paging-action="' + paging_action + '" transclude="true"></div>';
                        html += '</div>';
                    } else {
                        html += '<div paging class="page-num paging text-center" page="' + current + '" page-size="' + size + '" total="' + total + '" paging-action="' + paging_action + '" transclude="true"></div>';
                    }
                    html += '</div>';
                    html = html.replace(/%M%/g, modelKey);
                    $ele.html($compile(html)($scope));
                });
            }
        };
    }]);

==> landers.angular-2.1.62.tgz: package/src/control/directive-landers-pagebar.js <==
;angular.module('Landers.angular')
    .directive('pagebar', ['$compile', 'Flat', function($compile, Flat){
        return {
            restrict : 'A',
            link : function($scope, $ele, $attrs){
                var modelKey = $attrs['modelKey'];
                var pageinfo = Landers.utils.to.bool($attrs['pageinfo']);
                $scope.$watch (modelKey + '.$list', function($list){
                    if ( !$list ) return;

                    var current, total, size, last;
                    if ( $list.page ) {
                        current = '%M%.$list.page.current';
                        total = '%M%.$list.page.total';
                        size = '%M%.$list.page.size';
                        last = '%M%.$list.page.last';
                    } else {
                        current = '%M%.$list.current_page';
                        total = '%M%.$list.total';
                        size = '%M%.$list.per_page';
                        last = '%M%.$list.last_page';
                    }
                    var html = '', paging_action = $attrs['pagingAction'] || '%M%.$event.showPage(page)';
                    html += '<div ng-if="' + last + ' > 0 && ' + total + ' > 0 && ' + size + ' > 0">';
                    if (pageinfo) {
                        html += '<div class="fl page-info mr5">';
                        html += '   <ul class="hlist pageinfo">';
                        html += '       <li>页次：{{' + current + '}}/{{' + last + '}}</li>';
                        html += '       <li class="ml15">每页：{{' + size + '}}</li>';
                        html += '       <li class="ml15">总数：{{' + total + '}}</li>';
                        html += '       <li class="ml15" ng-show="%M%.$items.selected.length">选中: {{%M%.$items.selected.length}}</li>';
                        html += '   </ul>';
                        html += '</div>';
                        html += '<div class="fr ml5">';
                        html += '   <div class="page-num paging" paging page="' + current + '" page-size="' + size + '" total="' + total + '" paging-action="' + paging_action + '" transclude="true"></div>';
                        html += '</div>';
                    } else {
                        html += '<div paging class="page-num paging text-center" page="' + current + '" page-size="' + size + '" total="' + total + '" paging-action="' + paging_action + '" transclude="true"></div>';
                    }
                    html += '</div>';
                    html = html.replace(/%M%/g, modelKey);
                    $ele.html($compile(html)($scope));
                });
            }
        };
    }]);
